;;; LinGO grammar specific globals file
;;; parameters only - grammar specific functions
;;; should go in user-fns.lsp

; For character encoding

(defparameter excl:*locale* (excl::find-locale "pt_PT.UTF-8"))

(defparameter *active-parsing-p* t)

;;; Strings

(defparameter *toptype* '*top*)

(defparameter *string-type* 'string-literal
   "a special type name - any lisp strings are subtypes of it")

;;; Special features and types

(defparameter *orth-path* '(stem))

(defparameter *list-tail* '(rest))

(defparameter *list-head* '(first))

(defparameter *empty-list-type* 'null)

(defparameter *list-type* 'list)

(defparameter *diff-list-type* 'diff-list)

(defparameter *diff-list-list* 'list)

(defparameter *diff-list-last* 'last)

(defparameter *irregular-forms-only-p* t)

;;;
;;; input characters to be ignored (i.e. suppressed) in tokenization
;;;
;(defparameter *punctuation-characters*
;  (append
;   '(#\space #\! #\" #\& #\' #\(
;     #\) #\* #\+ #\, #\- #\. #\/ #\;
;     #\< #\= #\> #\? #\@ #\[ #\\ #\] #\^ #\_
;     #\` #\{ #\| #\} #\~)
;   #+:ics
;   '(#\ideographic_full_stop #\fullwidth_question_mark
;     #\horizontal_ellipsis #\fullwidth_full_stop
;     #\fullwidth_exclamation_mark #\black_circle
;     #\fullwidth_comma #\ideographic_space
;     #\katakana_middle_dot #\white_circle)))


(defparameter *display-type-hierarchy-on-load* nil)

;;; Parsing

(defparameter *chart-limit* 100)

(defparameter *maximum-number-of-edges* 4000)

(defparameter *mother-feature* NIL
  "The feature giving the mother in a grammar rule")

(defparameter *start-symbol* '(either-ep-or-bp-root)
  "specifing valid parses")

(defparameter *maximal-lex-rule-applications* 7
   "The number of lexical rule applications which may be made
   before it is assumed that some rules are applying circularly")

(defparameter *deleted-daughter-features*
  '(ARGS HEAD-DTR NON-HEAD-DTR DTR CONJ-DTR NONCONJ-DTR LCOORD-DTR RCOORD-DTR FILLER-DTR NON-FILLER-DTR ROOT-COMP MISSING-DTR VERB-DTR MISSING-VERB MISSING-PREPOSITION)
  "features pointing to daughters deleted on building a constituent")

;;; Parse tree node labels

;;; the path where the name string is stored
(defparameter *label-path* '(LABEL-NAME))

;;; the path for the meta prefix symbol
(defparameter *prefix-path* '(META-PREFIX))

;;; the path for the meta suffix symbol
(defparameter *suffix-path* '(META-SUFFIX))

;;; the path for the recursive category
(defparameter *recursive-path* '(SYNSEM NON-LOCAL SLASH LIST FIRST))

;;; the path inside the node to be unified with the recursive node
(defparameter *local-path* '(SYNSEM LOCAL))

;;; the path inside the node to be unified with the label node
(defparameter *label-fs-path* '())

(defparameter *label-template-type* 'label)

;;; for the compare function

(defparameter *discriminant-path* '(synsem local cont keys key pred))

;;; the lex-rule suffix defaults to _lex_rule, but this might
;;; not be desirable

;(setf *lex-rule-suffix* nil)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Parsing - Generation Mismatches

;;;
;;; Lexical items available for parsing but not used in generation
;;;

(defparameter *duplicate-lex-ids*
 '(agua bebé_feminine à-séria a+quando+de quando+antes de+sobremaneira
   tão+só tão+só_np-adjunct tão+pouco_np-adjunct prontos_discourse-marker
   a_predicational-preposition2 a_nonpredicational-np_or_vp-preposition2
   o_definite-article2 o_definite-article-nosem2 o_personal-pronoun2
   os_personal-pronoun2 e_plus-particle2 com_predicational-preposition2
   com_predicational-preposition3 com_nonpredicational-np-preposition2
   com_nonpredicational-np-preposition3 tar))


;;;
;;; Rules used in parsing but ignored by the generator
;;;

(setf *gen-ignore-rules*
  '(HEAD-COMP_PROCLITIC PUNCTUATION-COMMA))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Characterization

;;
;; Include support for characterization
;;
(setf *characterize-p* t)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Generation

;
;; Make generation faster
;; (adapted from the Delphin Wiki pages on Jacy, and from the ERG and
;; a post on the developers list)
;;


(setf *gen-packing-p* t)

(setf *gen-equate-qeqs-p* t)

(setf *packing-restrictor*  '(RELS HCONS STEM VARIANT SYSTEM))


; Use IAF or TPG, but not both

; Index Accessibility Filtering

(setf *gen-filtering-p* t)

(setf *intersective-rule-names* nil)

; Two-Phase Generation
; (it may no longer work)

; (setf *gen-filtering-p* nil)

; (setf *intersective-rule-names* '((head-functor-isect . (1)) (functor-head-hcomps-isect . (2)) (functor-head-fcomps-isect . (3))))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Idioms

;;
;; For IDIOMS
;; (from the Delphin Wiki pages on Jacy)
;;

(defparameter *non-idiom-root* 'root_non_idiom )


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; MT

;;; Say we can generate from Portuguese, and send generation messages only to
;;; servers that can generate from Portuguese

(setf *translate-grid* '(:pt . (:pt)))

