(in-package "MRS")

(defparameter *initial-semantics-path*
  `(,(vsym "SYNSEM") ,(vsym "LOCAL") ,(vsym "CONT"))
  "Following this path into a sign gets you to the MRS structure")


(defparameter *psoa-liszt-path* (list (vsym "RELS") (vsym "LIST"))
  "path to get a liszt from a psoa")

(defparameter *psoa-top-h-path*  `(,(vsym "HOOK") ,(vsym "LTOP"))
  "path to get the top handle from a psoa")

(defparameter *psoa-index-path*
  `(,(vsym "HOOK") ,(vsym "INDEX"))
  "path to get an index from a psoa")

(defparameter *psoa-event-path* `(,(vsym "HOOK") ,(vsym "INDEX")))
(defparameter *psoa-rh-cons-path* `(,(vsym "HCONS") ,(vsym "LIST")))

(defparameter *rel-handel-path*
    `(,(vsym "LBL"))
  "path to get the handel from a relation")

(defparameter *sc-arg-feature* (vsym "HARG")
  "the feature in a qeq that leads to the first argument")

(defparameter *outscpd-feature* (vsym "LARG")
  "the feature in a qeq that leads to the second argument")

(defparameter *bv-feature* (vsym "ARG0"))

(defparameter *scope-feat* (vsym "BODY"))

(defparameter *ignored-sem-features* (list (vsym "WLINK") (vsym "CFROM") (vsym "CTO"))
  "A list of features which are ignored completely")

;(defparameter *main-semantics-path*
;  `(,(vsym "SYNSEM") ,(vsym "LOCAL") ,(vsym "CONT")
;    ,(vsym "RELS") ,(vsym "LIST")))
;(defparameter *main-semantics-path*
;  (append *initial-semantics-path* (list (vsym "RELS") (vsym "LIST")))
;  "the path into a lexical entry which gives the list of
;   relations - typically (append *initial-semantics-path* '(RELS LIST))")
(defparameter *main-semantics-path*
  `(,(vsym "SYNSEM") ,(vsym "LOCAL") ,(vsym "CONT")
    ,(vsym "RELS") ,(vsym "LIST")))

(defparameter *construction-semantics-path*
  (list (vsym "C") (vsym "CONT") (vsym "RELS") (vsym "LIST"))
  "the path into a rule/construction which gives the
   semantics specific to that construction")

(defparameter *top-semantics-type* (vsym "predsort"))

(defparameter *value-feats*
  (list
   (vsym "CARG")
   (vsym "GREETING")
   (vsym "EXCLAMATION")))

(defparameter lkb::*semantics-index-path*
  (append *initial-semantics-path* (list (vsym "HOOK") (vsym "INDEX"))))

;;;
;;; types for variable naming in mrsoutput (copy from `src/mrs/mrsglobals.lsp'
;;; but here to remind us to adapt them, as appropriate).
;;;
#|
(defparameter *event-type* (vsym "event"))
(defparameter *event_or_index-type* (vsym "event_or_index"))
(defparameter *non_expl-ind-type* (vsym "non_expl-ind"))
(defparameter *eventtime-type* (vsym "eventtime"))
(defparameter *handle-type* (vsym "handle"))
(defparameter *group_lab-type* (vsym "group_lab"))
(defparameter *hole-type* (vsym "hole"))
(defparameter *label-type* (vsym "label"))
(defparameter *ref-ind-type* (vsym "ref-ind"))
(defparameter *full_ref-ind-type* (vsym "full_ref-ind"))
(defparameter *deg-ind-type* (vsym "deg-ind"))
(defparameter *individual-type* (vsym "individual"))
(defparameter *difference-list-type* (vsym "*diff-list*"))
(defparameter *conj-ind-type* (vsym "conj-ind"))
|#

(defparameter *event-type* (vsym "event"))
(defparameter *event_or_index-type* (vsym "event-or-ref-index"))
(defparameter *non_expl-ind-type* (vsym "index"))
(defparameter *handle-type* (vsym "handle"))
(defparameter *label-type* (vsym "handle"))
(defparameter *ref-ind-type* (vsym "ref-ind"))
(defparameter *individual-type* (vsym "individual"))
(defparameter *difference-list-type* (vsym "diff-list"))
(defparameter *conj-ind-type* (vsym "coord-index"))



(defun determine-variable-type (fs)
  (let ((type (create-type (fs-type fs))))
    (cond ((equal-or-subtype type *event-type*) "e")
          ((equal-or-subtype type *ref-ind-type*) "x")
          ((equal-or-subtype type *non_expl-ind-type*) "r")
          ((equal-or-subtype type *event_or_index-type*) "i")
          ((equal-or-subtype type *handle-type*) "h")
          ((equal-or-subtype type (vsym "integer")) "j")
          ((equal-or-subtype type (vsym "string-variable")) "s")
          (t "u"))))


;;;
;;; context condition in MRS munging rules
;;;

(defparameter *mrs-rule-condition-path* (list (vsym "CONTEXT")))

;;;
;;; ERB 2004-06-08
;;;

(setf *sem-relation-suffix* "_rel")
(setf *rel-name-path* `(,(vsym "PRED") ))

;;;
;;; To fix MRS scoping:
;;; FMC 2006-01-26
;;;
; Not necessary, since these features no longer appear in messages
;(defparameter *scoping-ignored-roles* (list (vsym "PASSIVIZED") (vsym "TOPICALIZED") (vsym "POSTPOSED")))


;;; These two are taken from Jacy
;;;
;;; INSTLOC is a feature that should appear on all feature structures
;;; representing variables (handles etc)  It is needed by the generator
;;; as a location for a constant value that distinguishes different
;;; variables.  It is now assumed to be string-valued.

(defparameter *instloc-path* `(,(vsym "INSTLOC")))

(defparameter *slash-semantics-path*
    `(,(vsym "SYNSEM") ,(vsym "NON-LOCAL")
      ,(vsym "SLASH") ,(vsym "LIST") ,(vsym "FIRST")
      ,(vsym "CONT"))
  "This path is used for filtering the edges in the generator to improve efficiency")
